
# q-expansion of newform 1100.6.b.b, downloaded from the LMFDB on 27 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1100
weight = 6
poly_data = [193600, 0, 881, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, -881, 0, -1], 440], [[0, 441, 0, 1], 220], [[441, 0, 1, 0], 1]]

hecke_ring_character_values = [[551, [1, 0, 0, 0]], [177, [-1, 0, 0, 0]], [101, [1, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0], [0, -1, -5, 0], [0, 0, 0, 0], [0, 5, 34, 0], [-121, 0, 0, 0], [0, 18, -398, 0], [0, -97, 56, 0], [-1716, 0, 0, -7], [0, 92, 1157, 0], [2446, 0, 0, 139], [-2288, 0, 0, 113], [0, 341, 691, 0], [9958, 0, 0, -248], [0, -300, -3800, 0], [0, 712, 5941, 0], [0, -441, -1911, 0], [-25700, 0, 0, 562], [-21798, 0, 0, -581], [0, -222, 2597, 0], [-84, 0, 0, -921], [0, 254, -23100, 0], [9576, 0, 0, -2818], [0, 2518, 22732, 0], [40658, 0, 0, -499], [0, -118, -25703, 0], [-83874, 0, 0, 1752], [0, 1214, -65169, 0], [0, -3912, 30306, 0], [82602, 0, 0, -3124], [0, 3022, 36211, 0], [0, 11616, -16564, 0], [153396, 0, 0, -237], [0, -2354, -72659, 0], [-217388, 0, 0, -7536], [194218, 0, 0, 7081], [-760, 0, 0, -3030], [0, 13889, -34463, 0], [0, 2811, -210509, 0], [0, 2249, -276232, 0], [0, -25170, -69636, 0], [67968, 0, 0, -28644], [466010, 0, 0, 6492], [10840, 0, 0, 1804], [0, 10469, -337188, 0], [0, -5416, 81644, 0], [329920, 0, 0, 22917], [-242020, 0, 0, -13605], [0, 14128, 138905, 0], [0, -22486, 18284, 0], [215266, 0, 0, -36408], [0, 4597, -75686, 0], [804400, 0, 0, 22954], [648662, 0, 0, -3084], [468328, 0, 0, 60118], [0, -14016, 119031, 0], [0, 50725, -556916, 0], [93790, 0, 0, 29686], [-401056, 0, 0, 39456], [0, 27068, -513926, 0], [-1065522, 0, 0, 10644], [0, 55894, -118240, 0], [0, -43514, -956102, 0], [0, 70214, 632710, 0], [-1702372, 0, 0, -10651], [0, 54816, 72925, 0], [0, -85977, 102225, 0], [-224700, 0, 0, 84328], [0, 143889, 378776, 0], [0, 79386, 949902, 0], [1612934, 0, 0, -40448], [0, 62908, 547081, 0], [1965696, 0, 0, -42720], [0, -34266, -1632091, 0], [0, -61262, -857356, 0], [1301116, 0, 0, -58650], [0, 72444, -491529, 0], [661182, 0, 0, 155340], [0, -14384, 2369805, 0], [3069014, 0, 0, 76709], [1283518, 0, 0, -4350], [-3691272, 0, 0, -147180], [3906902, 0, 0, 126678], [-2266792, 0, 0, 56840], [0, 81370, 1341047, 0], [-2302848, 0, 0, -44080], [0, -147206, -22001, 0], [86126, 0, 0, -160504], [0, 106257, -853450, 0], [-205386, 0, 0, -219957], [0, 358668, 543853, 0], [0, 49393, -1370555, 0], [-412544, 0, 0, -100604], [0, 58662, -4309471, 0], [-348908, 0, 0, -423953], [4503084, 0, 0, -133060], [0, 226732, -2771954, 0], [8196570, 0, 0, -6114], [-7083194, 0, 0, -9488], [0, -290152, -248262, 0], [3929966, 0, 0, 92013], [0, 55284, 3167408, 0], [0, -122942, 3331288, 0], [0, 467646, -5070, 0], [1853750, 0, 0, -129730], [11080876, 0, 0, -15367], [0, 162244, 1936641, 0], [0, -158729, 4018009, 0], [0, 102694, 5243344, 0], [3795236, 0, 0, -170461], [-4993946, 0, 0, -176608], [0, -580917, 1261652, 0], [0, 250394, -3391932, 0], [0, 290190, 1727001, 0], [6636952, 0, 0, -176664], [4387628, 0, 0, 431559], [6515450, 0, 0, 384149], [0, -152997, 5475235, 0], [0, -341696, 577783, 0], [0, 101573, -5991427, 0], [1492700, 0, 0, -720613], [-8057670, 0, 0, -440168], [0, -106267, -6791748, 0], [0, -673396, -2657302, 0], [0, 251329, 865261, 0], [5572088, 0, 0, -596814], [-11812838, 0, 0, -228389], [-5245226, 0, 0, -180012], [3882612, 0, 0, 294423], [0, -267060, -885661, 0], [0, 299640, 1469908, 0], [-3198692, 0, 0, 863676], [0, -571265, 3863116, 0], [3750756, 0, 0, 709369], [0, 340808, -8730995, 0], [2870218, 0, 0, 1088728], [-3158630, 0, 0, -748404], [0, 116987, -2492023, 0], [0, 817788, 1355438, 0], [0, -665044, 7318541, 0], [16487442, 0, 0, 150252], [-198276, 0, 0, -270371], [-10298446, 0, 0, -975904], [0, 446586, 11981239, 0], [0, -1375280, 918178, 0], [10006754, 0, 0, -547070], [-6548912, 0, 0, -1112024], [0, 354330, 2776264, 0], [0, 1402791, 558636, 0], [-29772880, 0, 0, -542810], [0, 1401052, -2248445, 0], [0, 841570, 5522976, 0], [16729422, 0, 0, -169884], [0, -888491, -8604865, 0], [0, -29728, 2566796, 0], [0, 65753, 17565121, 0], [14731280, 0, 0, -735433], [1476600, 0, 0, -1575736], [15602778, 0, 0, 1487379], [0, -693442, -4590662, 0], [-18139306, 0, 0, -1325059], [0, 1526479, 8425201, 0], [0, -118749, -2434206, 0], [0, -2062465, -4432832, 0], [7504060, 0, 0, -2403200], [0, -846126, -1397943, 0], [0, -1168324, 6587363, 0], [-23638816, 0, 0, 955080], [0, 314088, -2928856, 0], [6314482, 0, 0, 1604340], [0, -58845, 9903453, 0], [16117220, 0, 0, 31601], [5002570, 0, 0, -2128408], [-19079256, 0, 0, -1876278], [0, -639135, -5897306, 0], [-22540076, 0, 0, 897468], [-21018906, 0, 0, -1813857], [-18238116, 0, 0, -2390864], [37368998, 0, 0, 58274], [0, -596679, -14583962, 0], [34145978, 0, 0, -725267], [0, -417840, 22943819, 0], [-34728092, 0, 0, -2016389], [0, 1122909, -26116205, 0], [0, 3050871, 8213214, 0], [0, -414004, 14323721, 0], [28106854, 0, 0, -1234604], [0, 856740, 4267016, 0], [0, -755874, 6959893, 0], [-16905530, 0, 0, -2620788], [52087952, 0, 0, 1057004], [0, 1434718, 5288747, 0], [0, 2701668, -4949568, 0], [-8392560, 0, 0, 3560410], [-391870, 0, 0, -1619350], [0, -2393840, -4800488, 0], [0, 3544728, 5359041, 0], [2178494, 0, 0, 2778834], [0, 2719880, -321747, 0], [0, -468854, -44741426, 0], [0, 1088341, -5175404, 0], [4455014, 0, 0, 914363], [-1126136, 0, 0, 3309554], [0, -2765425, 1962499, 0], [-1134774, 0, 0, -2125462], [5404408, 0, 0, 674728], [0, -678055, -29054011, 0], [11176560, 0, 0, 4072832], [0, -1941212, -7523702, 0], [-94017142, 0, 0, -8188], [64528196, 0, 0, 2078112], [0, 1829409, 13148114, 0], [21187326, 0, 0, -1428594], [0, 3573366, 8323087, 0], [0, -2001665, -24287315, 0], [56923880, 0, 0, -1112572], [61907438, 0, 0, 536901], [0, -1241809, 22730854, 0], [13487370, 0, 0, -2822220], [0, 378630, -22435209, 0], [0, 4023257, 10449233, 0], [-56676398, 0, 0, -1678960], [-55386416, 0, 0, -3422550], [-70140434, 0, 0, -2674787], [0, -1923198, 30874711, 0], [0, 1393356, 17019930, 0], [14422498, 0, 0, 2129553], [0, 4196748, 1649703, 0], [37509888, 0, 0, 1367601], [0, 2758656, 16420016, 0], [-56284660, 0, 0, 2002856], [0, 1167156, -1110017, 0], [74470540, 0, 0, -680253], [86498248, 0, 0, 669962], [26015118, 0, 0, 1288752], [0, -2832010, -44516115, 0], [0, -1706889, 15480846, 0], [151490870, 0, 0, -607553], [0, 427582, 4035094, 0], [-106476908, 0, 0, 1894564], [-31021904, 0, 0, -20531], [0, -5849591, 17938567, 0], [135779540, 0, 0, 696984], [0, -967138, -71829885, 0], [7459102, 0, 0, 6019860], [0, 679230, -48029058, 0], [-147566328, 0, 0, -1055994], [0, -8409702, -8707135, 0], [23151752, 0, 0, -4896790], [8667508, 0, 0, -3703827], [0, -2118739, -26573104, 0], [0, 2661018, 32262698, 0], [99847226, 0, 0, 2194358], [0, 1683956, 37774859, 0], [-36704918, 0, 0, 2747115], [0, 1014180, 88181052, 0], [-52033876, 0, 0, 1850045], [-35225374, 0, 0, 3389982], [0, 4630782, 25631768, 0], [0, -1631224, -43143427, 0], [0, 9295773, 6143090, 0], [0, 4505184, 52024084, 0], [0, 7797540, 4784184, 0], [84064590, 0, 0, 1749161], [0, 3247058, -53731518, 0], [0, -4712662, 23130671, 0], [-2223524, 0, 0, -389784], [-3771090, 0, 0, -1959666], [-5501838, 0, 0, -3276657], [0, 5397324, 18241204, 0], [0, -193542, -10939110, 0], [-88942018, 0, 0, 3513108], [0, 2212091, -47977103, 0], [0, -4567806, 41367079, 0], [-116878760, 0, 0, -4926222], [0, 8223451, 24175002, 0], [0, -6486764, 32790725, 0], [0, 3346674, 13078281, 0], [-24457106, 0, 0, -6615588], [10477566, 0, 0, 1988152], [-40001900, 0, 0, 7405609], [0, -1684825, 88264136, 0], [-42430552, 0, 0, -52620], [0, 3090668, -2709022, 0], [132191918, 0, 0, 2880807], [0, 3745860, 83644724, 0], [-72316600, 0, 0, 8094233], [0, -4476912, 15664627, 0], [0, -2607030, -39427206, 0], [40743876, 0, 0, -12353491], [-125684170, 0, 0, 8050652], [-109380382, 0, 0, -2274178], [0, -5708878, 14955251, 0], [0, 4328769, 38272734, 0], [109700916, 0, 0, 2216661], [0, -5291010, 5820490, 0], [-36090046, 0, 0, 398984], [-45711500, 0, 0, -1140892], [0, -8287935, 32384841, 0], [227634404, 0, 0, -2645536], [0, 2574622, -20192658, 0], [0, -6407009, -46784938, 0], [0, -9957456, -42410952, 0], [-50504728, 0, 0, 6163048]]
